@@ -10,12 +10,13 @@ use MooX::StrictConstructor;
 use MooX::Types::MooseLike::Base qw(Str);
 use namespace::autoclean;
 
-our $VERSION = '1.017';
+our $VERSION = '1.018';
 
 with qw(
     Locale::TextDomain::OO::Role::Logger
 );
 
+my $is_too_late;
 sub load_plugins {
     my ( $class, @args ) = @_;
 
@@ -25,12 +26,15 @@ sub load_plugins {
         ref $plugins eq 'ARRAY'
             or confess 'Attribute plugins expected as ArrayRef';
         for my $plugin ( @{$plugins} ) {
+            $is_too_late
+                and confess 'Too late to load plugins, another method new was called before';
             my $package = ( 0 == index $plugin, q{+} )
                 ? $plugin
                 : "Locale::TextDomain::OO::Plugin::$plugin";
             with $package;
         }
     }
+    $is_too_late = 1;
 
     return \%arg_of;
 }
@@ -94,6 +98,28 @@ sub _calculate_multiplural_index {
     return $index;
 }
 
+# The reason we need that here is "gettext_to_maketext => 1" during load lexicon.
+# That escaps all [ ] before it is changing %1 to [_1] or similar.
+# And so all none gettext strings are also involved.
+my $escape_maketext = sub {
+    my $string = shift;
+
+    defined $string
+        or return $string;
+    $string =~ s{ ( [\[\]] ) }{~$1}xmsg;
+
+    return $string;
+};
+my $unescape_maketext = sub {
+    my $string = shift;
+
+    defined $string
+        or return $string;
+    $string =~ s{ [~] ( [\[\]] ) }{$1}xmsg;
+
+    return $string;
+};
+
 sub translate { ## no critic (ExcessComplexity ManyArgs)
     my ($self, $msgctxt, $msgid, $msgid_plural, $count, $is_n) = @_;
 
@@ -114,6 +140,13 @@ sub translate { ## no critic (ExcessComplexity ManyArgs)
         msgid        => $msgid,
         msgid_plural => $msgid_plural,
     });
+    my $maketext_msg_key = sub {
+        return $key_util->join_message_key({
+            msgctxt      => $escape_maketext->($msgctxt),
+            msgid        => $escape_maketext->($msgid),
+            msgid_plural => $escape_maketext->($msgid_plural),
+        });
+    };
     if ( $is_n ) {
         my $plural_code = $lexicon->{ q{} }->{plural_code}
             or confess qq{Plural-Forms not found in lexicon "$lexicon_key"};
@@ -122,6 +155,8 @@ sub translate { ## no critic (ExcessComplexity ManyArgs)
             : $plural_code->($count);
         my $msgstr_plural = exists $lexicon->{$msg_key}
             ? $lexicon->{$msg_key}->{msgstr_plural}->[$multiplural_index]
+            : exists $lexicon->{ $maketext_msg_key->() }
+            ? $unescape_maketext->( $lexicon->{ $maketext_msg_key->() }->{msgstr_plural}->[$multiplural_index] )
             : ();
         if ( ! defined $msgstr_plural ) { # fallback
             $msgstr_plural = $plural_code->($count)
@@ -152,6 +187,8 @@ sub translate { ## no critic (ExcessComplexity ManyArgs)
     }
     my $msgstr = exists $lexicon->{$msg_key}
         ? $lexicon->{$msg_key}->{msgstr}
+        : exists $lexicon->{ $maketext_msg_key->() }
+        ? $unescape_maketext->( $lexicon->{ $maketext_msg_key->() }->{msgstr} )
         : ();
     if ( ! defined $msgstr ) { # fallback
         $msgstr = $msgid;
@@ -205,7 +242,7 @@ $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk
 
 =head1 VERSION
 
-1.017
+1.018
 
 =head1 DESCRIPTION
 
@@ -282,7 +319,7 @@ Steffen Winkler
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2013 - 2017,
+Copyright (c) 2013 - 2015,
 Steffen Winkler
 C<< <steffenw at cpan.org> >>.
 All rights reserved.
